
:orphan:

.. _sphx_glr_auto_examples_sg_execution_times:

Computation times
=================
**02:47.077** total execution time for **auto_examples** files:

- **02:19.769**: :ref:`sphx_glr_auto_examples_example_kim_SW_Si.py` (``example_kim_SW_Si.py``)
- **00:27.308**: :ref:`sphx_glr_auto_examples_example_nn_Si.py` (``example_nn_Si.py``)
- **00:00.000**: :ref:`sphx_glr_auto_examples_example_linear_regression.py` (``example_linear_regression.py``)
